from __future__ import annotations

import requests

from osdu_client.exceptions import OSDUAPIError
from osdu_client.services.base import OSDUAPIClient
from osdu_client.utils import urljoin
from osdu_client.validation import validate_data

from .models import LegalTagDto, RequestLegalTags, SearchLegalTag, UpdateLegalTag


class LegalAPIError(OSDUAPIError):
    pass


class LegalClient(OSDUAPIClient):
    service_path = "/api/legal/v1/"

    def list_legaltags(
        self,
        *,
        valid: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if valid is not None:
            params["valid"] = valid

        url = urljoin(self.base_url, self.service_path, "legaltags")
        response = requests.get(url, headers=headers, params=params)
        if not response.ok:
            raise LegalAPIError(response.text, response.status_code)
        return response.json()

    def update_legaltag(
        self,
        *,
        name: str | None = None,
        contract_id: str | None = None,
        description: str | None = None,
        expiration_date: str | None = None,
        extension_properties: dict | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        data = {}
        if name is not None:
            data["name"] = name
        if contract_id is not None:
            data["contractId"] = contract_id
        if description is not None:
            data["description"] = description
        if expiration_date is not None:
            data["expirationDate"] = expiration_date
        if extension_properties is not None:
            data["extensionProperties"] = extension_properties

        if self.validation:
            validate_data(data, UpdateLegalTag, LegalAPIError)

        url = urljoin(self.base_url, self.service_path, "legaltags")
        response = requests.put(url, headers=headers, json=data)
        if not response.ok:
            raise LegalAPIError(response.text, response.status_code)
        return response.json()

    def create_legaltag(
        self,
        *,
        name: str | None = None,
        description: str | None = None,
        properties: dict | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        data = {}
        if name is not None:
            data["name"] = name
        if description is not None:
            data["description"] = description
        if properties is not None:
            data["properties"] = properties

        if self.validation:
            validate_data(data, LegalTagDto, LegalAPIError)

        url = urljoin(self.base_url, self.service_path, "legaltags")
        response = requests.post(url, headers=headers, json=data)
        if not response.ok:
            raise LegalAPIError(response.text, response.status_code)
        return response.json()

    def validate_legaltags(
        self,
        *,
        names: list[str],
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        data = {
            "names": names,
        }

        if self.validation:
            validate_data(data, RequestLegalTags, LegalAPIError)

        url = urljoin(self.base_url, self.service_path, "legaltags:validate")
        response = requests.post(url, headers=headers, json=data)
        if not response.ok:
            raise LegalAPIError(response.text, response.status_code)
        return response.json()

    def query_legaltags(
        self,
        *,
        query_list: list[str] | None = None,
        operator_list: list[str] | None = None,
        sort_by: str | None = None,
        sort_order: str | None = None,
        limit: int | None = None,
        valid: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if valid is not None:
            params["valid"] = valid

        data = {}
        if query_list is not None:
            data["queryList"] = query_list
        if operator_list is not None:
            data["operatorList"] = operator_list
        if sort_by is not None:
            data["sortBy"] = sort_by
        if sort_order is not None:
            data["sortOrder"] = sort_order
        if limit is not None:
            data["limit"] = limit

        if self.validation:
            validate_data(data, SearchLegalTag, LegalAPIError)

        url = urljoin(self.base_url, self.service_path, "legaltags:query")
        response = requests.post(url, headers=headers, params=params, json=data)
        if not response.ok:
            raise LegalAPIError(response.text, response.status_code)
        return response.json()

    def get_batch_legaltags(
        self,
        *,
        names: list[str],
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        data = {
            "names": names,
        }

        if self.validation:
            validate_data(data, RequestLegalTags, LegalAPIError)

        url = urljoin(self.base_url, self.service_path, "legaltags:batchRetrieve")
        response = requests.post(url, headers=headers, json=data)
        if not response.ok:
            raise LegalAPIError(response.text, response.status_code)
        return response.json()

    def get_legaltags_properties(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "legaltags:properties")
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise LegalAPIError(response.text, response.status_code)
        return response.json()

    def get_legaltag(
        self,
        *,
        name: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "legaltags/%s" % name)
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise LegalAPIError(response.text, response.status_code)
        return response.json()

    def delete_legaltag(
        self,
        *,
        name: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "legaltags/%s" % name)
        response = requests.delete(url, headers=headers)
        if not response.ok:
            raise LegalAPIError(response.text, response.status_code)
        return response.json()

    def get_legaltag_compliance_job_status(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "jobs/updateLegalTagStatus")
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise LegalAPIError(response.text, response.status_code)
        return response.json()

    def get_info(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "info")
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise LegalAPIError(response.text, response.status_code)
        return response.json()

    def get_readiness_check(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "_ah/readiness_check")
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise LegalAPIError(response.text, response.status_code)
        return response.json()

    def get_liveness_check(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "_ah/liveness_check")
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise LegalAPIError(response.text, response.status_code)
        return response.json()



from __future__ import annotations

from importlib import import_module

from osdu_client.auth import AuthBackendInterface
from osdu_client.exceptions import OSDUClientError
from osdu_client.services.base import OSDUAPIClient

DMS_NAMES = {
    "sdms": "SDMS",
    "pws": "PWS",
    "rafs": "RAFS",
    "welldelivery": "WellDelivery"
}


def get_service_client(name: str, version: str | None = None) -> type[OSDUAPIClient]:
    service_name = DMS_NAMES.get(name, name.capitalize())

    try:
        module = import_module(
            f"osdu_client.services.{name}"
        )
        available_versions = getattr(module, "VERSIONS", {})
        if available_versions:
            client_class = available_versions.get(
                version, getattr(module, "DEFAULT_VERSION")
            )
        else:
            client_class = getattr(module, f"{service_name}Client")
    except KeyError as e:
        raise OSDUClientError(
            f"Version {version} of a client {name} does not exist. Available: {available_versions}") from e
    except ImportError as e:
        raise OSDUClientError(f"Client for service {name} does not exist.") from e
    return client_class


class OSDUAPI:
    @staticmethod
    def client(service_name, auth_backend: AuthBackendInterface, version: str | None = None, validation: bool = True) -> OSDUAPIClient:
        client_class = get_service_client(service_name, version)
        return client_class(
            auth_backend=auth_backend,
            validation=validation,
        )



from __future__ import annotations

import requests

from osdu_client.exceptions import OSDUAPIError
from osdu_client.services.wellbore.common import WellboreCommonClient
from osdu_client.utils import urljoin
from osdu_client.validation import validate_data

from .models import CreateDataSessionRequest, Dip, UpdateSessionState


class WellboreAPIError(OSDUAPIError):
    pass


class WellboreClient(WellboreCommonClient):
    service_path = ""

    def get_alpha_logs_data(
        self,
        *,
        record_id: str,
        offset: str | None = None,
        limit: str | None = None,
        curves: str | None = None,
        describe: str | None = None,
        filter: str | None = None,
        orient: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if offset is not None:
            params["offset"] = offset
        if limit is not None:
            params["limit"] = limit
        if curves is not None:
            params["curves"] = curves
        if describe is not None:
            params["describe"] = describe
        if filter is not None:
            params["filter"] = filter
        if orient is not None:
            params["orient"] = orient

        url = urljoin(
            self.base_url, self.service_path, "alpha/ddms/v2/logs/%s/data" % record_id
        )
        response = requests.get(url, headers=headers, params=params)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def write_alpha_logs_data(
        self,
        *,
        record_id: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url, self.service_path, "alpha/ddms/v2/logs/%s/data" % record_id
        )
        response = requests.post(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def list_records_sessions_v2(
        self,
        *,
        record_id: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url,
            self.service_path,
            "alpha/ddms/v2/logs/%s/sessions" % record_id,
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def create_alpha_logs_sessions(
        self,
        *,
        mode: str,
        from_version: int | None = 0,
        meta: dict | None = None,
        time_to_live: int | None = "1440",
        record_id: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        request_data = {
            "mode": mode,
        }
        if from_version is not None:
            request_data["fromVersion"] = from_version
        if meta is not None:
            request_data["meta"] = meta
        if time_to_live is not None:
            request_data["timeToLive"] = time_to_live

        if self.validation:
            validate_data(request_data, CreateDataSessionRequest, WellboreAPIError)

        url = urljoin(
            self.base_url,
            self.service_path,
            "alpha/ddms/v2/logs/%s/sessions" % record_id,
        )
        response = requests.post(url, headers=headers, json=request_data)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_record_session_v2(
        self,
        *,
        record_id: str,
        session_id: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url,
            self.service_path,
            "alpha/ddms/v2/logs/%s/sessions/%s" % (record_id, session_id),
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def patch_alpha_logs_sessions(
        self,
        *,
        state: str,
        record_id: str,
        session_id: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        request_data = {
            "state": state,
        }

        if self.validation:
            validate_data(request_data, UpdateSessionState, WellboreAPIError)

        url = urljoin(
            self.base_url,
            self.service_path,
            "alpha/ddms/v2/logs/%s/sessions/%s" % (record_id, session_id),
        )
        response = requests.patch(url, headers=headers, json=request_data)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def send_alpha_logs_sessions_data(
        self,
        *,
        record_id: str,
        session_id: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url,
            self.service_path,
            "alpha/ddms/v2/logs/%s/sessions/%s/data" % (record_id, session_id),
        )
        response = requests.post(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_alpha_logs_versions_data(
        self,
        *,
        record_id: str,
        version: str,
        offset: str | None = None,
        limit: str | None = None,
        curves: str | None = None,
        describe: str | None = None,
        filter: str | None = None,
        orient: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if offset is not None:
            params["offset"] = offset
        if limit is not None:
            params["limit"] = limit
        if curves is not None:
            params["curves"] = curves
        if describe is not None:
            params["describe"] = describe
        if filter is not None:
            params["filter"] = filter
        if orient is not None:
            params["orient"] = orient

        url = urljoin(
            self.base_url,
            self.service_path,
            "alpha/ddms/v2/logs/%s/versions/%s/data" % (record_id, version),
        )
        response = requests.get(url, headers=headers, params=params)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def create_or_update_dipset(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "ddms/v2/dipsets")
        response = requests.post(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def delete_dipset(
        self,
        *,
        dipsetid: str,
        recursive: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if recursive is not None:
            params["recursive"] = recursive

        url = urljoin(self.base_url, self.service_path, "ddms/v2/dipsets/%s" % dipsetid)
        response = requests.delete(url, headers=headers, params=params)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_dipset(
        self,
        *,
        dipsetid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "ddms/v2/dipsets/%s" % dipsetid)
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_dip(
        self,
        *,
        dipsetid: str,
        index: str | None = None,
        limit: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if index is not None:
            params["index"] = index
        if limit is not None:
            params["limit"] = limit

        url = urljoin(
            self.base_url, self.service_path, "ddms/v2/dipsets/%s/dips" % dipsetid
        )
        response = requests.get(url, headers=headers, params=params)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def define_dips_dipset(
        self,
        *,
        dipsetid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url, self.service_path, "ddms/v2/dipsets/%s/dips" % dipsetid
        )
        response = requests.post(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def insert_dip_in_dipset(
        self,
        *,
        dipsetid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url,
            self.service_path,
            "ddms/v2/dipsets/%s/dips/insert" % dipsetid,
        )
        response = requests.post(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def query_dip_from_dipset(
        self,
        *,
        dipsetid: str,
        min_reference: str | None = None,
        max_reference: str | None = None,
        classification: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if min_reference is not None:
            params["minReference"] = min_reference
        if max_reference is not None:
            params["maxReference"] = max_reference
        if classification is not None:
            params["classification"] = classification

        url = urljoin(
            self.base_url, self.service_path, "ddms/v2/dipsets/%s/dips/query" % dipsetid
        )
        response = requests.get(url, headers=headers, params=params)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def delete_dip(
        self,
        *,
        dipsetid: str,
        index: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url,
            self.service_path,
            "ddms/v2/dipsets/%s/dips/%s" % (dipsetid, index),
        )
        response = requests.delete(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_dip_at_index(
        self,
        *,
        dipsetid: str,
        index: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url,
            self.service_path,
            "ddms/v2/dipsets/%s/dips/%s" % (dipsetid, index),
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def update_dip(
        self,
        *,
        azimuth: dict,
        inclination: dict,
        reference: dict,
        classification: str | None = None,
        quality: dict | None = None,
        x_coordinate: dict | None = None,
        y_coordinate: dict | None = None,
        z_coordinate: dict | None = None,
        dipsetid: str,
        index: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        request_data = {
            "azimuth": azimuth,
            "inclination": inclination,
            "reference": reference,
        }
        if classification is not None:
            request_data["classification"] = classification
        if quality is not None:
            request_data["quality"] = quality
        if x_coordinate is not None:
            request_data["xCoordinate"] = x_coordinate
        if y_coordinate is not None:
            request_data["yCoordinate"] = y_coordinate
        if z_coordinate is not None:
            request_data["zCoordinate"] = z_coordinate

        if self.validation:
            validate_data(request_data, Dip, WellboreAPIError)

        url = urljoin(
            self.base_url,
            self.service_path,
            "ddms/v2/dipsets/%s/dips/%s" % (dipsetid, index),
        )
        response = requests.patch(url, headers=headers, json=request_data)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_versions_dipset(
        self,
        *,
        dipsetid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url, self.service_path, "ddms/v2/dipsets/%s/versions" % dipsetid
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_dipsets_versions(
        self,
        *,
        dipsetid: str,
        version: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url,
            self.service_path,
            "ddms/v2/dipsets/%s/versions/%s" % (dipsetid, version),
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def create_or_update_logs(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "ddms/v2/logs")
        response = requests.post(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def delete_log(
        self,
        *,
        logid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "ddms/v2/logs/%s" % logid)
        response = requests.delete(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_log(
        self,
        *,
        logid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "ddms/v2/logs/%s" % logid)
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_log_data(
        self,
        *,
        logid: str,
        orient: str | None = None,
        bulk_path: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if orient is not None:
            params["orient"] = orient
        if bulk_path is not None:
            params["bulk-path"] = bulk_path

        url = urljoin(self.base_url, self.service_path, "ddms/v2/logs/%s/data" % logid)
        response = requests.get(url, headers=headers, params=params)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def write_log_data(
        self,
        *,
        logid: str,
        orient: str | None = None,
        bulk_path: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if orient is not None:
            params["orient"] = orient
        if bulk_path is not None:
            params["bulk-path"] = bulk_path

        url = urljoin(self.base_url, self.service_path, "ddms/v2/logs/%s/data" % logid)
        response = requests.post(url, headers=headers, params=params)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_decimated_log(
        self,
        *,
        logid: str,
        quantiles: str | None = None,
        start: str | None = None,
        stop: str | None = None,
        orient: str | None = None,
        bulk_path: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if quantiles is not None:
            params["quantiles"] = quantiles
        if start is not None:
            params["start"] = start
        if stop is not None:
            params["stop"] = stop
        if orient is not None:
            params["orient"] = orient
        if bulk_path is not None:
            params["bulk-path"] = bulk_path

        url = urljoin(
            self.base_url, self.service_path, "ddms/v2/logs/%s/decimated" % logid
        )
        response = requests.get(url, headers=headers, params=params)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_log_statistics(
        self,
        *,
        logid: str,
        bulk_path: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if bulk_path is not None:
            params["bulk-path"] = bulk_path

        url = urljoin(
            self.base_url, self.service_path, "ddms/v2/logs/%s/statistics" % logid
        )
        response = requests.get(url, headers=headers, params=params)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def upload_log_data(
        self,
        *,
        logid: str,
        orient: str | None = None,
        bulk_path: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if orient is not None:
            params["orient"] = orient
        if bulk_path is not None:
            params["bulk-path"] = bulk_path

        url = urljoin(
            self.base_url, self.service_path, "ddms/v2/logs/%s/upload_data" % logid
        )
        response = requests.post(url, headers=headers, params=params)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_log_versions(
        self,
        *,
        logid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url, self.service_path, "ddms/v2/logs/%s/versions" % logid
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_log_version(
        self,
        *,
        logid: str,
        version: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url,
            self.service_path,
            "ddms/v2/logs/%s/versions/%s" % (logid, version),
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_log_version_data(
        self,
        *,
        logid: str,
        version: str,
        orient: str | None = None,
        bulk_path: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if orient is not None:
            params["orient"] = orient
        if bulk_path is not None:
            params["bulk-path"] = bulk_path

        url = urljoin(
            self.base_url,
            self.service_path,
            "ddms/v2/logs/%s/versions/%s/data" % (logid, version),
        )
        response = requests.get(url, headers=headers, params=params)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def create_or_update_logsets(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "ddms/v2/logsets")
        response = requests.post(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def delete_logset(
        self,
        *,
        logsetid: str,
        recursive: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if recursive is not None:
            params["recursive"] = recursive

        url = urljoin(self.base_url, self.service_path, "ddms/v2/logsets/%s" % logsetid)
        response = requests.delete(url, headers=headers, params=params)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_logset(
        self,
        *,
        logsetid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "ddms/v2/logsets/%s" % logsetid)
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_logset_versions(
        self,
        *,
        logsetid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url, self.service_path, "ddms/v2/logsets/%s/versions" % logsetid
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_logset_version(
        self,
        *,
        logsetid: str,
        version: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url,
            self.service_path,
            "ddms/v2/logsets/%s/versions/%s" % (logsetid, version),
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def create_or_update_marker(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "ddms/v2/markers")
        response = requests.post(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def delete_marker(
        self,
        *,
        markerid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "ddms/v2/markers/%s" % markerid)
        response = requests.delete(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_marker(
        self,
        *,
        markerid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "ddms/v2/markers/%s" % markerid)
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_marker_versions(
        self,
        *,
        markerid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url, self.service_path, "ddms/v2/markers/%s/versions" % markerid
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_marker_version(
        self,
        *,
        markerid: str,
        version: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url,
            self.service_path,
            "ddms/v2/markers/%s/versions/%s" % (markerid, version),
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def create_or_update_trajectories(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "ddms/v2/trajectories")
        response = requests.post(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def delete_trajectory(
        self,
        *,
        trajectoryid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url, self.service_path, "ddms/v2/trajectories/%s" % trajectoryid
        )
        response = requests.delete(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_trajectory(
        self,
        *,
        trajectoryid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url, self.service_path, "ddms/v2/trajectories/%s" % trajectoryid
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_trajectory_data(
        self,
        *,
        trajectoryid: str,
        channels: str | None = None,
        orient: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if channels is not None:
            params["channels"] = channels
        if orient is not None:
            params["orient"] = orient

        url = urljoin(
            self.base_url,
            self.service_path,
            "ddms/v2/trajectories/%s/data" % trajectoryid,
        )
        response = requests.get(url, headers=headers, params=params)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def create_trajectory_data(
        self,
        *,
        trajectoryid: str,
        orient: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if orient is not None:
            params["orient"] = orient

        url = urljoin(
            self.base_url,
            self.service_path,
            "ddms/v2/trajectories/%s/data" % trajectoryid,
        )
        response = requests.post(url, headers=headers, params=params)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_trajectory_versions(
        self,
        *,
        trajectoryid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url,
            self.service_path,
            "ddms/v2/trajectories/%s/versions" % trajectoryid,
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_trajectory_version(
        self,
        *,
        trajectoryid: str,
        version: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url,
            self.service_path,
            "ddms/v2/trajectories/%s/versions/%s" % (trajectoryid, version),
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_trajectory_version_data(
        self,
        *,
        trajectoryid: str,
        version: str,
        channels: str | None = None,
        orient: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if channels is not None:
            params["channels"] = channels
        if orient is not None:
            params["orient"] = orient

        url = urljoin(
            self.base_url,
            self.service_path,
            "ddms/v2/trajectories/%s/versions/%s/data" % (trajectoryid, version),
        )
        response = requests.get(url, headers=headers, params=params)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def create_or_update_wellbore_v2(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "ddms/v2/wellbores")
        response = requests.post(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def delete_wellbores(
        self,
        *,
        wellboreid: str,
        recursive: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if recursive is not None:
            params["recursive"] = recursive

        url = urljoin(
            self.base_url, self.service_path, "ddms/v2/wellbores/%s" % wellboreid
        )
        response = requests.delete(url, headers=headers, params=params)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_wellbores(
        self,
        *,
        wellboreid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url, self.service_path, "ddms/v2/wellbores/%s" % wellboreid
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_versions_wellbore(
        self,
        *,
        wellboreid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url,
            self.service_path,
            "ddms/v2/wellbores/%s/versions" % wellboreid,
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_wellbores_versions(
        self,
        *,
        wellboreid: str,
        version: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url,
            self.service_path,
            "ddms/v2/wellbores/%s/versions/%s" % (wellboreid, version),
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def create_or_update_well(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "ddms/v2/wells")
        response = requests.post(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def delete_well(
        self,
        *,
        wellid: str,
        recursive: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if recursive is not None:
            params["recursive"] = recursive

        url = urljoin(self.base_url, self.service_path, "ddms/v2/wells/%s" % wellid)
        response = requests.delete(url, headers=headers, params=params)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_well_v2(
        self,
        *,
        wellid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "ddms/v2/wells/%s" % wellid)
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_well_versions_v2(
        self,
        *,
        wellid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url, self.service_path, "ddms/v2/wells/%s/versions" % wellid
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()

    def get_well_version(
        self,
        *,
        wellid: str,
        version: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url,
            self.service_path,
            "ddms/v2/wells/%s/versions/%s" % (wellid, version),
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise WellboreAPIError(response.text, response.status_code)
        return response.json()



# generated by datamodel-codegen:
#   filename:  swagger.yaml
#   timestamp: 2024-07-12T07:32:21+00:00

from __future__ import annotations

from enum import Enum
from typing import Any, Dict, List, Optional

from pydantic import BaseModel, Field, constr


class Acl(BaseModel):
    viewers: Optional[List[str]] = None
    owners: Optional[List[str]] = None


class Status(Enum):
    compliant = "compliant"
    incompliant = "incompliant"


class Legal(BaseModel):
    legaltags: Optional[List[str]] = Field(None)
    otherRelevantDataCountries: List[str] = Field(...)
    status: Optional[Status] = None


class RecordAncestry(BaseModel):
    parents: Optional[List[str]] = Field(None)


class AppError(BaseModel):
    code: Optional[int] = None
    reason: Optional[str] = None
    message: Optional[str] = None


class GetDatasetStorageInstructionsResponse(BaseModel):
    storageLocation: Optional[Dict[str, Dict[str, Any]]] = None
    providerKey: Optional[str] = None


class GetDatasetRegistryRequest(BaseModel):
    datasetRegistryIds: List[str] = Field(..., max_items=20, min_items=1)


class DatasetRetrievalProperties(BaseModel):
    datasetRegistryId: Optional[str] = None
    retrievalProperties: Optional[Dict[str, Dict[str, Any]]] = None
    providerKey: Optional[str] = None


class RetrievalInstructionsResponse(BaseModel):
    datasets: Optional[List[DatasetRetrievalProperties]] = None


class ConnectedOuterService(BaseModel):
    name: Optional[str] = None
    version: Optional[str] = None


class VersionInfo(BaseModel):
    groupId: Optional[str] = None
    artifactId: Optional[str] = None
    version: Optional[str] = None
    buildTime: Optional[str] = None
    branch: Optional[str] = None
    commitId: Optional[str] = None
    commitMessage: Optional[str] = None
    connectedOuterServices: Optional[List[ConnectedOuterService]] = None


class Record(BaseModel):
    id: Optional[constr(pattern=r"^[\w\-\.]+:[\w\-\.]+:[\w\-\.\:\%]+$")] = None
    version: Optional[int] = None
    kind: Optional[str] = None
    acl: Acl
    legal: Optional[Legal] = None
    data: Dict[str, Dict[str, Any]]
    ancestry: Optional[RecordAncestry] = None
    meta: Optional[List[Dict[str, Dict[str, Any]]]] = None
    tags: Optional[Dict[str, str]] = None


class GetCreateUpdateDatasetRegistryResponse(BaseModel):
    datasetRegistries: Optional[List[Record]] = None


class CreateDatasetRegistryRequest(BaseModel):
    datasetRegistries: List[Record] = Field(..., max_items=20, min_items=1)



from __future__ import annotations

import requests

from osdu_client.exceptions import OSDUAPIError
from osdu_client.services.base import OSDUAPIClient
from osdu_client.utils import urljoin
from osdu_client.validation import validate_data

from .models import CreateAction, Ddms, Record, Secret, Subscription, TestAction


class RegisterAPIError(OSDUAPIError):
    pass


class RegisterClient(OSDUAPIClient):
    service_path = "/api/register/v1"

    def get_ddms(
        self,
        *,
        id: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "ddms/%s" % id)
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise RegisterAPIError(response.text, response.status_code)
        return response.json()

    def delete_ddms(
        self,
        *,
        id: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "ddms/%s" % id)
        response = requests.delete(url, headers=headers)
        if not response.ok:
            raise RegisterAPIError(response.text, response.status_code)
        return response.json()

    def create_ddms(
        self,
        *,
        id: str | None = None,
        name: str | None = None,
        description: str | None = None,
        contact_email: str | None = None,
        interfaces: list[dict] | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        request_data = {}
        if id is not None:
            request_data["id"] = id
        if name is not None:
            request_data["name"] = name
        if description is not None:
            request_data["description"] = description
        if contact_email is not None:
            request_data["contactEmail"] = contact_email
        if interfaces is not None:
            request_data["interfaces"] = interfaces

        if self.validation:
            validate_data(request_data, Ddms, RegisterAPIError)

        url = urljoin(self.base_url, self.service_path, "ddms")
        response = requests.post(url, headers=headers, json=request_data)
        if not response.ok:
            raise RegisterAPIError(response.text, response.status_code)
        return response.json()

    def query_ddms(
        self,
        *,
        type: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {
            "type": type,
        }

        url = urljoin(self.base_url, self.service_path, "ddms")
        response = requests.get(url, headers=headers, params=params)
        if not response.ok:
            raise RegisterAPIError(response.text, response.status_code)
        return response.json()

    def get_d(
        self,
        *,
        id: str,
        type: str,
        localid: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url, self.service_path, "ddms/%s/%s/%s" % (id, type, localid)
        )
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise RegisterAPIError(response.text, response.status_code)
        return response.json()

    def get_action(
        self,
        *,
        id: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "action/%s" % id)
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise RegisterAPIError(response.text, response.status_code)
        return response.json()

    def delete_action(
        self,
        *,
        id: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "action/%s" % id)
        response = requests.delete(url, headers=headers)
        if not response.ok:
            raise RegisterAPIError(response.text, response.status_code)
        return response.json()

    def create_action(
        self,
        *,
        id: str | None = None,
        name: str | None = None,
        description: str | None = None,
        contact_email: str | None = None,
        img: str | None = None,
        url: str | None = None,
        filter: dict | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        request_data = {}
        if id is not None:
            request_data["id"] = id
        if name is not None:
            request_data["name"] = name
        if description is not None:
            request_data["description"] = description
        if contact_email is not None:
            request_data["contactEmail"] = contact_email
        if img is not None:
            request_data["img"] = img
        if url is not None:
            request_data["url"] = url
        if filter is not None:
            request_data["filter"] = filter

        if self.validation:
            validate_data(request_data, CreateAction, RegisterAPIError)

        url = urljoin(self.base_url, self.service_path, "action")
        response = requests.post(url, headers=headers, json=request_data)
        if not response.ok:
            raise RegisterAPIError(response.text, response.status_code)
        return response.json()

    def create_action_test(
        self,
        *,
        action: dict | None = None,
        test_payload: dict | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        request_data = {}
        if action is not None:
            request_data["action"] = action
        if test_payload is not None:
            request_data["testPayload"] = test_payload

        if self.validation:
            validate_data(request_data, TestAction, RegisterAPIError)

        url = urljoin(self.base_url, self.service_path, "action:test")
        response = requests.post(url, headers=headers, json=request_data)
        if not response.ok:
            raise RegisterAPIError(response.text, response.status_code)
        return response.json()

    def create_action_get(
        self,
        *,
        id: str | None = None,
        kind: str | None = None,
        acl: dict | None = None,
        legal: dict | None = None,
        data: dict | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        request_data = {}
        if id is not None:
            request_data["id"] = id
        if kind is not None:
            request_data["kind"] = kind
        if acl is not None:
            request_data["acl"] = acl
        if legal is not None:
            request_data["legal"] = legal
        if data is not None:
            request_data["data"] = data

        if self.validation:
            validate_data(request_data, Record, RegisterAPIError)

        url = urljoin(self.base_url, self.service_path, "action:retrieve")
        response = requests.post(url, headers=headers, json=request_data)
        if not response.ok:
            raise RegisterAPIError(response.text, response.status_code)
        return response.json()

    def create_subscription(
        self,
        *,
        name: str | None = None,
        description: str | None = None,
        topic: str | None = None,
        push_endpoint: str | None = None,
        secret: dict | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        request_data = {}
        if name is not None:
            request_data["name"] = name
        if description is not None:
            request_data["description"] = description
        if topic is not None:
            request_data["topic"] = topic
        if push_endpoint is not None:
            request_data["pushEndpoint"] = push_endpoint
        if secret is not None:
            request_data["secret"] = secret

        if self.validation:
            validate_data(request_data, Subscription, RegisterAPIError)

        url = urljoin(self.base_url, self.service_path, "subscription")
        response = requests.post(url, headers=headers, json=request_data)
        if not response.ok:
            raise RegisterAPIError(response.text, response.status_code)
        return response.json()

    def get_subscription(
        self,
        *,
        id: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "subscription/%s" % id)
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise RegisterAPIError(response.text, response.status_code)
        return response.json()

    def delete_subscription(
        self,
        *,
        id: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "subscription/%s" % id)
        response = requests.delete(url, headers=headers)
        if not response.ok:
            raise RegisterAPIError(response.text, response.status_code)
        return response.json()

    def update_subscription_secret(
        self,
        *,
        secret_type: str | None = None,
        value: dict | None = None,
        id: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        request_data = {}
        if secret_type is not None:
            request_data["secretType"] = secret_type
        if value is not None:
            request_data["value"] = value

        if self.validation:
            validate_data(request_data, Secret, RegisterAPIError)

        url = urljoin(self.base_url, self.service_path, "subscription/%s/secret" % id)
        response = requests.put(url, headers=headers, json=request_data)
        if not response.ok:
            raise RegisterAPIError(response.text, response.status_code)
        return response.json()

    def get_topics(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "topics")
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise RegisterAPIError(response.text, response.status_code)
        return response.json()

    def get_info(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "info")
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise RegisterAPIError(response.text, response.status_code)
        return response.json()



from __future__ import annotations

import requests

from osdu_client.exceptions import OSDUAPIError
from osdu_client.services.base import OSDUAPIClient
from osdu_client.utils import urljoin
from osdu_client.validation import validate_data

from .models import SchemaRequest


class SchemaAPIError(OSDUAPIError):
    pass


class SchemaClient(OSDUAPIClient):
    service_path = "/api/schema-service/v1"

    def update_schemas_system(
        self,
        *,
        schema_info: dict,
        schema: dict,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        data = {
            "schemaInfo": schema_info,
            "schema": schema,
        }

        if self.validation:
            validate_data(data, SchemaRequest, SchemaAPIError)

        url = urljoin(self.base_url, self.service_path, "schemas/system")
        response = requests.put(url, headers=headers, json=data)
        if not response.ok:
            raise SchemaAPIError(response.text, response.status_code)
        return response.json()

    def search_schemas(
        self,
        *,
        authority: str | None = None,
        source: str | None = None,
        entity_type: str | None = None,
        schema_version_major: str | None = None,
        schema_version_minor: str | None = None,
        schema_version_patch: str | None = None,
        status: str | None = None,
        scope: str | None = None,
        latest_version: str | None = None,
        limit: str | None = None,
        offset: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if authority is not None:
            params["authority"] = authority
        if source is not None:
            params["source"] = source
        if entity_type is not None:
            params["entityType"] = entity_type
        if schema_version_major is not None:
            params["schemaVersionMajor"] = schema_version_major
        if schema_version_minor is not None:
            params["schemaVersionMinor"] = schema_version_minor
        if schema_version_patch is not None:
            params["schemaVersionPatch"] = schema_version_patch
        if status is not None:
            params["status"] = status
        if scope is not None:
            params["scope"] = scope
        if latest_version is not None:
            params["latestVersion"] = latest_version
        if limit is not None:
            params["limit"] = limit
        if offset is not None:
            params["offset"] = offset

        url = urljoin(self.base_url, self.service_path, "schema")
        response = requests.get(url, headers=headers, params=params)
        if not response.ok:
            raise SchemaAPIError(response.text, response.status_code)
        return response.json()

    def update_schema(
        self,
        *,
        schema_info: dict,
        schema: dict,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        data = {
            "schemaInfo": schema_info,
            "schema": schema,
        }

        if self.validation:
            validate_data(data, SchemaRequest, SchemaAPIError)

        url = urljoin(self.base_url, self.service_path, "schema")
        response = requests.put(url, headers=headers, json=data)
        if not response.ok:
            raise SchemaAPIError(response.text, response.status_code)
        return response.json()

    def create_schema(
        self,
        *,
        schema_info: dict,
        schema: dict,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        data = {
            "schemaInfo": schema_info,
            "schema": schema,
        }

        if self.validation:
            validate_data(data, SchemaRequest, SchemaAPIError)

        url = urljoin(self.base_url, self.service_path, "schema")
        response = requests.post(url, headers=headers, json=data)
        if not response.ok:
            raise SchemaAPIError(response.text, response.status_code)
        return response.json()

    def get_schema(
        self,
        *,
        id: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "schema/%s" % id)
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise SchemaAPIError(response.text, response.status_code)
        return response.json()

    def get_liveness_check(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "liveness_check")
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise SchemaAPIError(response.text, response.status_code)
        return response.json()

    def get_info(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "info")
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise SchemaAPIError(response.text, response.status_code)
        return response.json()



# generated by datamodel-codegen:
#   filename:  swagger.yaml
#   timestamp: 2024-07-12T07:32:22+00:00

from __future__ import annotations

from enum import Enum
from typing import List, Optional, Union

from pydantic import BaseModel, Field


class BodyCompilePartiallyEvaluateAQueryApiPolicyV1CompilePost(BaseModel):
    file: bytes = Field(..., title="File")


class BodyCreateOrUpdatePartitionPolicyApiPolicyV1PoliciesOsduPartitionDataPartitionPolicyIdPut(
    BaseModel
):
    file: bytes = Field(..., title="File")


class BodyEvaluatePolicyApiPolicyV1EvaluationsQueryPost(BaseModel):
    file: bytes = Field(..., title="File")


class BodyValidatePolicyApiPolicyV1ValidatePolicyIdPut(BaseModel):
    file: bytes = Field(..., title="File")


class Operation(Enum):
    view = "view"
    create = "create"
    update = "update"
    delete = "delete"
    purge = "purge"


class Input(BaseModel):
    operation: Operation = Field(..., title="Operation")
    groups: Optional[List[str]] = Field([""], title="Groups")
    xuserid: Optional[str] = Field("", title="Xuserid")
    token: Optional[str] = Field("", title="Token")
    datapartitionid: Optional[str] = Field("", title="Datapartitionid")


class ServiceDetail(BaseModel):
    version: Optional[str] = Field(..., title="Version")


class Services(BaseModel):
    opa: ServiceDetail


class TranslateItem(BaseModel):
    query: str = Field(..., title="Query")
    input: Input
    unknowns: List[str] = Field(..., title="Unknowns")


class ValidationError(BaseModel):
    loc: List[Union[str, int]] = Field(..., title="Location")
    msg: str = Field(..., title="Message")
    type: str = Field(..., title="Error Type")


class HTTPValidationError(BaseModel):
    detail: Optional[List[ValidationError]] = Field(None, title="Detail")


class InfoOut(BaseModel):
    version: str = Field(..., title="Version")
    artifactId: Optional[str] = Field(..., title="Artifactid")
    name: Optional[str] = Field(..., title="Name")
    groupId: Optional[str] = Field(..., title="Groupid")
    buildTime: Optional[str] = Field(..., title="Buildtime")
    branch: Optional[str] = Field(..., title="Branch")
    commitId: Optional[str] = Field(..., title="Commitid")
    commitMessage: Optional[str] = Field(..., title="Commitmessage")
    connectedOuterServices: Services



from __future__ import annotations

import re

FORBIDDEN_NAMES = {
    "from": "_form"
}


def urljoin(*args) -> str:
    return "/".join(map(lambda x: str(x).rstrip('/').lstrip('/'), [arg for arg in args if arg]))


def convert_to_snake_case(name: str) -> str:
    result = re.sub(r'(?<!^)(?=[A-Z])', '_', name).lower().replace("-", "_")
    if result in FORBIDDEN_NAMES:
        return FORBIDDEN_NAMES[result]
    return result



from __future__ import annotations

from abc import ABCMeta

from osdu_client.auth import AuthBackendInterface


class OSDUAPIClient(metaclass=ABCMeta):
    def __init__(self, auth_backend: AuthBackendInterface, base_url: str | None = None, validation: bool = True):
        self.auth = auth_backend
        self.base_url = base_url or auth_backend.base_url
        self.validation = validation



from __future__ import annotations

import requests

from osdu_client.exceptions import OSDUAPIError
from osdu_client.services.base import OSDUAPIClient
from osdu_client.utils import urljoin
from osdu_client.validation import validate_data

from .models import DeliveryGetFileSignedURLRequest, FileListRequest, FileLocationRequest, LocationRequest, Record


class FileAPIError(OSDUAPIError):
    pass


class FileClient(OSDUAPIClient):
    service_path = ""

    def get_location(
        self,
        *,
        file_id: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        data = {}
        if file_id is not None:
            data["FileID"] = file_id

        if self.validation:
            validate_data(data, LocationRequest, FileAPIError)

        url = urljoin(self.base_url, self.service_path, "v2/getLocation")
        response = requests.post(url, headers=headers, json=data)
        if not response.ok:
            raise FileAPIError(response.text, response.status_code)
        return response.json()

    def get_files_upload_url(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "v2/files/uploadURL")
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise FileAPIError(response.text, response.status_code)
        return response.json()

    def create_files_metadata(
        self,
        *,
        kind: str,
        acl: dict,
        legal: dict,
        data: dict,
        id: str | None = None,
        ancestry: dict | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        data = {
            "kind": kind,
            "acl": acl,
            "legal": legal,
            "data": data,
        }
        if id is not None:
            data["id"] = id
        if ancestry is not None:
            data["ancestry"] = ancestry

        if self.validation:
            validate_data(data, Record, FileAPIError)

        url = urljoin(self.base_url, self.service_path, "v2/files/metadata")
        response = requests.post(url, headers=headers, json=data)
        if not response.ok:
            raise FileAPIError(response.text, response.status_code)
        return response.json()

    def get_files_metadata(
        self,
        *,
        id: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "v2/files/%s/metadata" % id)
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise FileAPIError(response.text, response.status_code)
        return response.json()

    def delete_files_metadata(
        self,
        *,
        id: str,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "v2/files/%s/metadata" % id)
        response = requests.delete(url, headers=headers)
        if not response.ok:
            raise FileAPIError(response.text, response.status_code)
        return response.json()

    def gets_url_to_download_file(
        self,
        *,
        id: str,
        expiry_time: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        params = {}
        if expiry_time is not None:
            params["expiryTime"] = expiry_time

        url = urljoin(self.base_url, self.service_path, "v2/files/%s/downloadURL" % id)
        response = requests.get(url, headers=headers, params=params)
        if not response.ok:
            raise FileAPIError(response.text, response.status_code)
        return response.json()

    def get_file_location(
        self,
        *,
        file_id: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        data = {}
        if file_id is not None:
            data["FileID"] = file_id

        if self.validation:
            validate_data(data, FileLocationRequest, FileAPIError)

        url = urljoin(self.base_url, self.service_path, "v2/getFileLocation")
        response = requests.post(url, headers=headers, json=data)
        if not response.ok:
            raise FileAPIError(response.text, response.status_code)
        return response.json()

    def get_file_signed_url(
        self,
        *,
        srn: list[str] | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        data = {}
        if srn is not None:
            data["srn"] = srn

        if self.validation:
            validate_data(data, DeliveryGetFileSignedURLRequest, FileAPIError)

        url = urljoin(self.base_url, self.service_path, "v2/delivery/getFileSignedUrl")
        response = requests.post(url, headers=headers, json=data)
        if not response.ok:
            raise FileAPIError(response.text, response.status_code)
        return response.json()

    def get_file_list(
        self,
        *,
        time_from: str | None = None,
        time_to: str | None = None,
        page_num: int | None = None,
        items: int | None = None,
        user_id: str | None = None,
        data_partition_id: str | None = None,
        tenant: str | None = None,
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        data = {}
        if time_from is not None:
            data["TimeFrom"] = time_from
        if time_to is not None:
            data["TimeTo"] = time_to
        if page_num is not None:
            data["PageNum"] = page_num
        if items is not None:
            data["Items"] = items
        if user_id is not None:
            data["UserID"] = user_id

        if self.validation:
            validate_data(data, FileListRequest, FileAPIError)

        url = urljoin(self.base_url, self.service_path, "v2/getFileList")
        response = requests.post(url, headers=headers, json=data)
        if not response.ok:
            raise FileAPIError(response.text, response.status_code)
        return response.json()

    def get_info(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "v2/info")
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise FileAPIError(response.text, response.status_code)
        return response.json()

    def get_file_collections_storage_instructions(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url, self.service_path, "v2/file-collections/storageInstructions"
        )
        response = requests.post(url, headers=headers)
        if not response.ok:
            raise FileAPIError(response.text, response.status_code)
        return response.json()

    def get_file_collections_retrieval_instructions(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(
            self.base_url,
            self.service_path,
            "v2/file-collections/retrievalInstructions",
        )
        response = requests.post(url, headers=headers)
        if not response.ok:
            raise FileAPIError(response.text, response.status_code)
        return response.json()

    def copy_file_collections(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "v2/file-collections/copy")
        response = requests.post(url, headers=headers)
        if not response.ok:
            raise FileAPIError(response.text, response.status_code)
        return response.json()



from __future__ import annotations

import requests

from osdu_client.exceptions import OSDUAPIError
from osdu_client.services.base import OSDUAPIClient
from osdu_client.utils import urljoin


class RAFSAPIError(OSDUAPIError):
    pass


class RAFSCommonClient(OSDUAPIClient):
    service_path = ""

    def get_metrics(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "metrics")
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise RAFSAPIError(response.text, response.status_code)
        return response.json()

    def get_info(
        self, data_partition_id: str | None = None, tenant: str | None = None
    ) -> dict:
        headers = self.auth.get_headers()
        if data_partition_id:
            headers["data-partition-id"] = data_partition_id
        if tenant:
            headers["tenant"] = tenant

        url = urljoin(self.base_url, self.service_path, "api/rafs-ddms/info")
        response = requests.get(url, headers=headers)
        if not response.ok:
            raise RAFSAPIError(response.text, response.status_code)
        return response.json()
